#include <pi-todo.h>
#include "../jpilot_src/libplugin.h"
#include "pytype_basics.h"

extern PyObject* PyPiTodo_New();
extern PyObject* PyPiTodo_Wrap(struct ToDo*, PCRecType, unsigned int, unsigned char,
			      int, void*, PyObject *);

extern PyTypeObject TodoType;

#define PyPiTodo_Check(v)          ((v)->ob_type == &TodoType)

typedef struct {
  PyObject_HEAD
  PyObject_JPTYPE
  struct ToDo a;
} PyPiTodo;
